@@ -1,10 +1,15 @@
 #! /usr/bin/env python
 
 from unit_timeside import *
-from timeside.decoder import *
-from timeside.analyzer import Yaafe
-from yaafelib import DataFlow,FeaturePlan
+from timeside.decoder.file import FileDecoder
+from timeside import _WITH_YAAFE
+if _WITH_YAAFE:
+    from timeside.analyzer.yaafe import Yaafe
+    from yaafelib import DataFlow, FeaturePlan
+import os
 
+
+@unittest.skipIf(not _WITH_YAAFE, 'Yaafe library is not available')
 class TestYaafe(unittest.TestCase):
 
     def setUp(self):
