@@ -19,3 +19,12 @@ def check_samples():
             u = urllib.urlopen(url+sample)
             f.write(u.read())
             f.close()
+
+
+def tmp_file_sink(prefix=None, suffix = None):
+    import tempfile
+    tmpfile = tempfile.NamedTemporaryFile(delete=True,
+                                          prefix=prefix,
+                                          suffix=suffix)
+    tmpfile.close()
+    return tmpfile.name
\ No newline at end of file
